@@ -1,13 +1,13 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
-use serde::de::{Deserialize, Deserializer, SeqAccess, Visitor};
-use serde::ser::{Serialize, SerializeSeq, Serializer};
-
 use std::fmt;
 
-use crate::Buffer;
-use crate::BufferList;
-use crate::BufferListRef;
+use serde::{
+    de::{Deserialize, Deserializer, SeqAccess, Visitor},
+    ser::{Serialize, SerializeSeq, Serializer},
+};
+
+use crate::{Buffer, BufferList, BufferListRef};
 
 impl Serialize for BufferListRef {
     fn serialize<S: Serializer>(&self, serializer: S) -> Result<S::Ok, S::Error> {
@@ -61,8 +61,7 @@ impl<'de> Deserialize<'de> for BufferList {
 
 #[cfg(test)]
 mod tests {
-    use crate::BufferList;
-    use crate::ClockTime;
+    use crate::{BufferList, ClockTime};
 
     #[test]
     fn test_serialize() {
@@ -107,9 +106,7 @@ mod tests {
                 "        duration: Some(4),",
                 "        offset: 0,",
                 "        offset_end: 4,",
-                "        flags: (",
-                "            bits: 0,",
-                "        ),",
+                "        flags: \"\",",
                 "        buffer: \"AQIDBA==\",",
                 "    ),",
                 "    (",
@@ -118,9 +115,7 @@ mod tests {
                 "        duration: Some(2),",
                 "        offset: 4,",
                 "        offset_end: 6,",
-                "        flags: (",
-                "            bits: 0,",
-                "        ),",
+                "        flags: \"\",",
                 "        buffer: \"BQY=\",",
                 "    ),",
                 "]"
@@ -142,9 +137,7 @@ mod tests {
                     duration: Some(4),
                     offset: 0,
                     offset_end: 4,
-                    flags: (
-                        bits: 0,
-                    ),
+                    flags: "",
                     buffer: "AQIDBA==",
                 ),
                 (
@@ -153,9 +146,7 @@ mod tests {
                     duration: Some(2),
                     offset: 4,
                     offset_end: 6,
-                    flags: (
-                        bits: 0,
-                    ),
+                    flags: "",
                     buffer: "BQY=",
                 ),
             ]
